#!/bin/sh

ACTION=${1}
shift 1

get_image() {
  IMAGE_NAME="wordpress:latest"
}

do_install_detail() {
  local config=`uci get wordpress.@wordpress[0].config_path 2>/dev/null`
  local port=`uci get wordpress.@wordpress[0].port 2>/dev/null`
  local IMAGE_NAME=`uci get wordpress.@wordpress[0].image_name 2>/dev/null`
  local username=`uci get wordpress.@wordpress[0].username 2>/dev/null`
  local password=`uci get wordpress.@wordpress[0].password 2>/dev/null`

  #Generate the generic environment variables for the docker-compose

  GEN_PASS=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  GEN_PASS2=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  
  # Get our local LAN IP Address
  LAN_IP=$(uci get network.lan.ipaddr)
  # Strip trailing network mask
  LAN_IP="${LAN_IP%/*}"
   
  if [ -z "$config" ]; then
      echo "config path is empty!"
      exit 1
  fi

  [ -z "$port" ] && port=88
  [ -z "$IMAGE_NAME" ] && IMAGE_NAME=wordpress:latest

  
  # Create Docker Compose file with custom variables
   
  # Create Docker Compose file with custom variables
touch docker-compose.yml
cat > docker-compose.yml <<EOF
version: '3'

services:
  wp:
    image: wordpress:latest # https://hub.docker.com/_/wordpress/
    ports:
      - ${LAN_IP}:$port:80 # change ip if required
    volumes:
      - ./config/php.conf.ini:/usr/local/etc/php/conf.d/conf.ini
      - ./wp-app:/var/www/html # Full wordpress project
    environment:
      WORDPRESS_DB_HOST: db
      WORDPRESS_DB_NAME: wordpress
      WORDPRESS_DB_USER: root
      WORDPRESS_DB_PASSWORD: ${GEN_PASS}
    depends_on:
      - db
    links:
      - db

  wpcli:
    image: wordpress:cli
    volumes:
      - ./config/php.conf.ini:/usr/local/etc/php/conf.d/conf.ini
      - ./wp-app:/var/www/html
    environment:
      WORDPRESS_DB_HOST: db
      WORDPRESS_DB_NAME: wordpress
      WORDPRESS_DB_USER: root
      WORDPRESS_DB_PASSWORD: ${GEN_PASS}
    depends_on:
      - db
      - wp

  pma:
    image: phpmyadmin/phpmyadmin
    environment:
      # https://docs.phpmyadmin.net/en/latest/setup.html#docker-environment-variables
      PMA_HOST: db
      PMA_PORT: 3306
      MYSQL_ROOT_PASSWORD: ${GEN_PASS}
      UPLOAD_LIMIT: 300M
    ports:
      - ${LAN_IP}:8989:80
    links:
      - db:db

  db:
    image: mysql:latest # https://hub.docker.com/_/mysql/ - or mariadb https://hub.docker.com/_/mariadb
    ports:
      - ${LAN_IP}:3306:3306 # change ip if required
    command: [
        '--default_authentication_plugin=mysql_native_password',
        '--character-set-server=utf8mb4',
        '--collation-server=utf8mb4_unicode_ci'
    ]
    volumes:
      - ./wp-data:/docker-entrypoint-initdb.d
      - ./db_data:/var/lib/mysql
    environment:
      MYSQL_DATABASE: wordpress
      MYSQL_ROOT_PASSWORD: ${GEN_PASS}

volumes:
  db_data:
    labels:
      plugsy.name: "Wordpress"
      plugsy.category: "Home"
      plugsy.icon: "@styled-icons/boxicons-logos/WordPress"
      plugsy.link: "http://${LAN_IP}:$port"
EOF
  
  docker-compose up -d
 
  # Add a new list option to the "shortcutmenu" configuration file
  uci add shortcutmenu lists
  uci set shortcutmenu.@lists[-1].webname="$IMAGE_NAME"
  uci set shortcutmenu.@lists[-1].weburl="$LAN_IP:$port"
  uci set shortcutmenu.@lists[-1].webpath="/"
  uci commit shortcutmenu

}

usage() {
  echo "usage: $0 sub-command"
  echo "where sub-command is one of:"
  echo "      install                Install wordpress"
  echo "      upgrade                Upgrade wordpress"
  echo "      rm/start/stop/restart  Remove/Start/Stop/Restart wordpress"
  echo "      status                 wordpress status"
  echo "      port                   wordpress port"
}

case ${ACTION} in
  "install")
    get_image
    do_install_detail
  ;;
  "upgrade")
    get_image
    do_install_detail
  ;;
  "rm")
    docker rm -f wordpress
  ;;
  "start" | "stop" | "restart")
    docker ${ACTION} wordpress
  ;;
  "status")
    docker ps --all -f 'name=wordpress' --format '{{.State}}'
  ;;
  "port")
    docker ps --all -f 'name=wordpress' --format '{{.Ports}}' | grep -om1 '0.0.0.0:[0-9]*' | sed 's/0.0.0.0://'
  ;;
  *)
    usage
    exit 1
  ;;
esac
